@@ -17,7 +17,7 @@ from typing import Iterator
 from eva.executor.abstract_executor import AbstractExecutor
 from eva.models.storage.batch import Batch
 from eva.parser.types import ParserOrderBySortType
-from eva.planner.orderby_plan import OrderByPlan
+from eva.plan_nodes.orderby_plan import OrderByPlan
 
 
 class OrderByExecutor(AbstractExecutor):
