@@ -57,28 +57,26 @@ class Binder:
 
     @staticmethod
     def build_opr_tree_from_pre_order_repr(pre_order_repr: tuple) -> Operator:
-        if isinstance(pre_order_repr, Operator):
-            return pre_order_repr
-        else:
-            opr_tree = pre_order_repr[0]
-            opr_tree.children.clear()
-            if len(pre_order_repr) > 1:
-                # remove old children
-                for child in pre_order_repr[1:]:
-                    opr_tree.append_child(
-                        Binder.build_opr_tree_from_pre_order_repr(child)
-                    )
-            return opr_tree
+        opr_tree = pre_order_repr[0]
+        assert isinstance(
+            opr_tree, Operator
+        ), f"Unknown operator encountered, expected Operator found {type(opr_tree)}"
+        # We should not modify the operator in the group
+        # expression as it might be used in later rules. Hack:
+        # Creating a copy of the match Potential fix: Store only
+        # the content in the group expression and manage the
+        # parent-child relationship separately. Refer
+        # optimizer_context:_xform_opr_to_group_expr
+        opr_tree = copy.copy(opr_tree)
+        opr_tree.children.clear()
+        if len(pre_order_repr) > 1:
+            # remove old children
+            for child in pre_order_repr[1:]:
+                opr_tree.append_child(Binder.build_opr_tree_from_pre_order_repr(child))
+        return opr_tree
 
     def __iter__(self):
         # the iterator only returns one match, which stems from the root node
         for match in Binder._binder(self._grp_expr, self._pattern, self._memo):
-            # We should not modify the operator in the group
-            # expression as it might be used in later rules. Hack:
-            # Creating a copy of the match Potential fix: Store only
-            # the content in the group expression and manage the
-            # parent-child relationship separately. Refer
-            # optimizer_context:_xform_opr_to_group_expr
-            match_copy = [copy.copy(opr) for opr in match]
-            x = Binder.build_opr_tree_from_pre_order_repr(match_copy)
+            x = Binder.build_opr_tree_from_pre_order_repr(match)
             yield x
