@@ -18,7 +18,7 @@ from eva.optimizer.optimizer_context import OptimizerContext
 from eva.optimizer.optimizer_task_stack import OptimizerTaskStack
 from eva.optimizer.optimizer_tasks import BottomUpRewrite, OptimizeGroup, TopDownRewrite
 from eva.optimizer.property import PropertyType
-from eva.optimizer.rules.rules import RulesManager
+from eva.optimizer.rules.rules_manager import RulesManager
 
 
 class PlanGenerator:
