@@ -16,6 +16,8 @@ from __future__ import annotations
 
 from typing import TYPE_CHECKING
 
+from eva.catalog.catalog_type import TableType
+from eva.catalog.catalog_utils import is_video_table
 from eva.expression.expression_utils import conjuction_list_to_expression_tree
 from eva.optimizer.optimizer_utils import (
     extract_equi_join_keys,
@@ -25,12 +27,12 @@ from eva.optimizer.optimizer_utils import (
 from eva.optimizer.rules.pattern import Pattern
 from eva.optimizer.rules.rules_base import Promise, Rule, RuleType
 from eva.parser.types import JoinType
-from eva.planner.create_mat_view_plan import CreateMaterializedViewPlan
-from eva.planner.explain_plan import ExplainPlan
-from eva.planner.hash_join_build_plan import HashJoinBuildPlan
-from eva.planner.predicate_plan import PredicatePlan
-from eva.planner.project_plan import ProjectPlan
-from eva.planner.show_info_plan import ShowInfoPlan
+from eva.plan_nodes.create_mat_view_plan import CreateMaterializedViewPlan
+from eva.plan_nodes.explain_plan import ExplainPlan
+from eva.plan_nodes.hash_join_build_plan import HashJoinBuildPlan
+from eva.plan_nodes.predicate_plan import PredicatePlan
+from eva.plan_nodes.project_plan import ProjectPlan
+from eva.plan_nodes.show_info_plan import ShowInfoPlan
 
 if TYPE_CHECKING:
     from eva.optimizer.optimizer_context import OptimizerContext
@@ -39,6 +41,7 @@ from eva.configuration.configuration_manager import ConfigurationManager
 from eva.optimizer.operators import (
     Dummy,
     LogicalCreate,
+    LogicalCreateIndex,
     LogicalCreateMaterializedView,
     LogicalCreateUDF,
     LogicalDrop,
@@ -63,24 +66,25 @@ from eva.optimizer.operators import (
     Operator,
     OperatorType,
 )
-from eva.planner.create_plan import CreatePlan
-from eva.planner.create_udf_plan import CreateUDFPlan
-from eva.planner.drop_plan import DropPlan
-from eva.planner.drop_udf_plan import DropUDFPlan
-from eva.planner.function_scan_plan import FunctionScanPlan
-from eva.planner.groupby_plan import GroupByPlan
-from eva.planner.hash_join_probe_plan import HashJoinProbePlan
-from eva.planner.insert_plan import InsertPlan
-from eva.planner.lateral_join_plan import LateralJoinPlan
-from eva.planner.limit_plan import LimitPlan
-from eva.planner.load_data_plan import LoadDataPlan
-from eva.planner.orderby_plan import OrderByPlan
-from eva.planner.rename_plan import RenamePlan
-from eva.planner.sample_plan import SamplePlan
-from eva.planner.seq_scan_plan import SeqScanPlan
-from eva.planner.storage_plan import StoragePlan
-from eva.planner.union_plan import UnionPlan
-from eva.planner.upload_plan import UploadPlan
+from eva.plan_nodes.create_index_plan import CreateIndexPlan
+from eva.plan_nodes.create_plan import CreatePlan
+from eva.plan_nodes.create_udf_plan import CreateUDFPlan
+from eva.plan_nodes.drop_plan import DropPlan
+from eva.plan_nodes.drop_udf_plan import DropUDFPlan
+from eva.plan_nodes.function_scan_plan import FunctionScanPlan
+from eva.plan_nodes.groupby_plan import GroupByPlan
+from eva.plan_nodes.hash_join_probe_plan import HashJoinProbePlan
+from eva.plan_nodes.insert_plan import InsertPlan
+from eva.plan_nodes.lateral_join_plan import LateralJoinPlan
+from eva.plan_nodes.limit_plan import LimitPlan
+from eva.plan_nodes.load_data_plan import LoadDataPlan
+from eva.plan_nodes.orderby_plan import OrderByPlan
+from eva.plan_nodes.rename_plan import RenamePlan
+from eva.plan_nodes.sample_plan import SamplePlan
+from eva.plan_nodes.seq_scan_plan import SeqScanPlan
+from eva.plan_nodes.storage_plan import StoragePlan
+from eva.plan_nodes.union_plan import UnionPlan
+from eva.plan_nodes.upload_plan import UploadPlan
 
 ##############################################
 # REWRITE RULES START
@@ -99,7 +103,7 @@ class EmbedFilterIntoGet(Rule):
         # System supports predicate pushdown only while reading video data
         predicate = before.predicate
         lget: LogicalGet = before.children[0]
-        if predicate and lget.dataset_metadata.is_video:
+        if predicate and is_video_table(lget.dataset_metadata):
             # System only supports pushing basic range predicates on id
             video_alias = lget.video.alias
             col_alias = f"{video_alias}.id"
@@ -148,7 +152,7 @@ class EmbedSampleIntoGet(Rule):
     def check(self, before: LogicalSample, context: OptimizerContext):
         # System supports sample pushdown only while reading video data
         lget: LogicalGet = before.children[0]
-        if lget.dataset_metadata.is_video:
+        if lget.dataset_metadata.table_type == TableType.VIDEO_DATA:
             return True
         return False
 
@@ -397,7 +401,7 @@ class LogicalDropToPhysical(Rule):
         return True
 
     def apply(self, before: LogicalDrop, context: OptimizerContext):
-        after = DropPlan(before.table_refs, before.if_exists)
+        after = DropPlan(before.table_infos, before.if_exists)
         return after
 
 
@@ -424,6 +428,27 @@ class LogicalCreateUDFToPhysical(Rule):
         return after
 
 
+class LogicalCreateIndexToFaiss(Rule):
+    def __init__(self):
+        pattern = Pattern(OperatorType.LOGICALCREATEINDEX)
+        super().__init__(RuleType.LOGICAL_CREATE_INDEX_TO_FAISS, pattern)
+
+    def promise(self):
+        return Promise.LOGICAL_CREATE_INDEX_TO_FAISS
+
+    def check(self, before: Operator, context: OptimizerContext):
+        return True
+
+    def apply(self, before: LogicalCreateIndex, context: OptimizerContext):
+        after = CreateIndexPlan(
+            before.name,
+            before.table_ref,
+            before.col_list,
+            before.index_type,
+        )
+        return after
+
+
 class LogicalDropUDFToPhysical(Rule):
     def __init__(self):
         pattern = Pattern(OperatorType.LOGICALDROPUDF)
@@ -479,7 +504,7 @@ class LogicalLoadToPhysical(Rule):
         if config_batch_mem_size:
             batch_mem_size = config_batch_mem_size
         after = LoadDataPlan(
-            before.table_metainfo,
+            before.table_info,
             before.path,
             batch_mem_size,
             before.column_list,
@@ -513,7 +538,7 @@ class LogicalUploadToPhysical(Rule):
         after = UploadPlan(
             before.path,
             before.video_blob,
-            before.table_metainfo,
+            before.table_info,
             batch_mem_size,
             before.column_list,
             before.file_options,
