@@ -20,8 +20,9 @@ import pandas as pd
 import torch
 from facenet_pytorch import MTCNN
 
-from eva.udfs.abstract_udf import AbstractClassifierUDF
+from eva.udfs.abstract.abstract_udf import AbstractClassifierUDF
 from eva.udfs.gpu_compatible import GPUCompatible
+from eva.utils.logging_manager import logger
 
 
 class FaceDetector(AbstractClassifierUDF, GPUCompatible):
@@ -30,11 +31,14 @@ class FaceDetector(AbstractClassifierUDF, GPUCompatible):
         threshold (float): Threshold for classifier confidence score
     """
 
-    def __init__(self, threshold=0.85):
-        super().__init__()
+    def setup(self, threshold=0.85):
         self.threshold = threshold
         self.model = MTCNN()
 
+    @property
+    def name(self) -> str:
+        return "FaceDetector"
+
     def to_device(self, device: str):
         gpu = "cuda:{}".format(device)
         self.model = MTCNN(device=torch.device(gpu))
@@ -44,7 +48,7 @@ class FaceDetector(AbstractClassifierUDF, GPUCompatible):
     def labels(self) -> List[str]:
         return []
 
-    def classify(self, frames: pd.DataFrame) -> pd.DataFrame:
+    def forward(self, frames: pd.DataFrame) -> pd.DataFrame:
         """
         Performs predictions on input frames
         Arguments:
@@ -63,8 +67,11 @@ class FaceDetector(AbstractClassifierUDF, GPUCompatible):
             pred_boxes = []
             pred_scores = []
             if frame_boxes is not None and frame_scores is not None:
-                pred_boxes = frame_boxes
-                pred_scores = frame_scores
+                if not np.isnan(pred_boxes):
+                    pred_boxes = np.asarray(frame_boxes, dtype="int")
+                    pred_scores = frame_scores
+                else:
+                    logger.warn(f"Nan entry in box {frame_boxes}")
             outcome = outcome.append(
                 {"bboxes": pred_boxes, "scores": pred_scores},
                 ignore_index=True,
