@@ -20,7 +20,9 @@ import mock
 import pytest
 
 from eva.catalog.catalog_manager import CatalogManager
+from eva.configuration.constants import EVA_ROOT_DIR
 from eva.server.command_handler import execute_query_fetch_all
+from eva.udfs.udf_bootstrap_queries import Mvit_udf_query
 
 
 class PytorchTest(unittest.TestCase):
@@ -28,15 +30,12 @@ class PytorchTest(unittest.TestCase):
     def setUpClass(cls):
         CatalogManager().reset()
         copy_sample_videos_to_upload_dir()
-        query = """LOAD FILE 'ua_detrac.mp4'
-                   INTO MyVideo;"""
-        execute_query_fetch_all(query)
-        query = """LOAD FILE 'mnist.mp4'
-                   INTO MNIST;"""
-        execute_query_fetch_all(query)
-        query = """LOAD FILE 'actions.mp4'
-                   INTO Actions;"""
-        execute_query_fetch_all(query)
+        ua_detrac = f"{EVA_ROOT_DIR}/data/ua_detrac/ua_detrac.mp4"
+        mnist = f"{EVA_ROOT_DIR}/data/mnist/mnist.mp4"
+        actions = f"{EVA_ROOT_DIR}/data/actions/actions.mp4"
+        execute_query_fetch_all(f"LOAD VIDEO '{ua_detrac}' INTO MyVideo;")
+        execute_query_fetch_all(f"LOAD VIDEO '{mnist}' INTO MNIST;")
+        execute_query_fetch_all(f"LOAD VIDEO '{actions}' INTO Actions;")
         load_inbuilt_udfs()
 
     @classmethod
@@ -44,6 +43,9 @@ class PytorchTest(unittest.TestCase):
         file_remove("ua_detrac.mp4")
         file_remove("mnist.mp4")
         file_remove("actions.mp4")
+        execute_query_fetch_all("DROP TABLE IF EXISTS Actions;")
+        execute_query_fetch_all("DROP TABLE IF EXISTS Mnist;")
+        execute_query_fetch_all("DROP TABLE IF EXISTS MyVideo;")
 
     @pytest.mark.torchtest
     def test_should_run_pytorch_and_fastrcnn(self):
@@ -52,6 +54,13 @@ class PytorchTest(unittest.TestCase):
         actual_batch = execute_query_fetch_all(select_query)
         self.assertEqual(len(actual_batch), 5)
 
+    @pytest.mark.torchtest
+    def test_should_run_pytorch_and_yolo(self):
+        select_query = """SELECT YoloV5(data) FROM MyVideo
+                        WHERE id < 5;"""
+        actual_batch = execute_query_fetch_all(select_query)
+        self.assertEqual(len(actual_batch), 5)
+
     @pytest.mark.torchtest
     def test_should_run_pytorch_and_ssd(self):
         create_udf_query = """CREATE UDF SSDObjectDetector
@@ -73,6 +82,8 @@ class PytorchTest(unittest.TestCase):
 
     @pytest.mark.torchtest
     def test_should_run_pytorch_and_mvit(self):
+
+        execute_query_fetch_all(Mvit_udf_query)
         select_query = """SELECT FIRST(id), MVITActionRecognition(SEGMENT(data)) FROM Actions
                        GROUP BY '16f';"""
         actual_batch = execute_query_fetch_all(select_query)
@@ -84,6 +95,8 @@ class PytorchTest(unittest.TestCase):
 
     @pytest.mark.torchtest
     def test_should_run_pytorch_and_fastrcnn_and_mvit(self):
+        execute_query_fetch_all(Mvit_udf_query)
+
         select_query = """SELECT FIRST(id),
                                  FastRCNNObjectDetector(FIRST(data)),
                                  MVITActionRecognition(SEGMENT(data))
