@@ -36,6 +36,7 @@ from eva.optimizer.operators import (
     LogicalUnion,
 )
 from eva.optimizer.statement_to_opr_convertor import StatementToPlanConvertor
+from eva.parser.create_index_statement import CreateIndexStatement
 from eva.parser.create_statement import CreateTableStatement
 from eva.parser.create_udf_statement import CreateUDFStatement
 from eva.parser.drop_statement import DropTableStatement
@@ -219,6 +220,15 @@ statement_to_opr_convertor.column_definition_to_udf_io"
         mock.assert_called_once()
         mock.assert_called_with(stmt)
 
+    def test_visit_should_call_create_index(self):
+        stmt = MagicMock(spec=CreateIndexStatement)
+        convertor = StatementToPlanConvertor()
+        mock = MagicMock()
+        convertor.visit_create_index = mock
+        convertor.visit(stmt)
+        mock.assert_called_once()
+        mock.assert_called_with(stmt)
+
     def test_should_return_false_for_unequal_plans_and_true_for_equal_plans(
         self,
     ):
