@@ -15,15 +15,20 @@
 import unittest
 from pathlib import Path
 
-from eva.catalog.column_type import ColumnType, NdArrayType
+from eva.catalog.catalog_type import ColumnType, IndexType, NdArrayType
 from eva.expression.abstract_expression import ExpressionType
 from eva.expression.comparison_expression import ComparisonExpression
 from eva.expression.constant_value_expression import ConstantValueExpression
 from eva.expression.function_expression import FunctionExpression
 from eva.expression.tuple_value_expression import TupleValueExpression
 from eva.parser.alias import Alias
+from eva.parser.create_index_statement import CreateIndexStatement
 from eva.parser.create_mat_view_statement import CreateMaterializedViewStatement
-from eva.parser.create_statement import ColConstraintInfo, ColumnDefinition
+from eva.parser.create_statement import (
+    ColConstraintInfo,
+    ColumnDefinition,
+    CreateTableStatement,
+)
 from eva.parser.create_udf_statement import CreateUDFStatement
 from eva.parser.drop_statement import DropTableStatement
 from eva.parser.drop_udf_statement import DropUDFStatement
@@ -42,6 +47,39 @@ class ParserTests(unittest.TestCase):
     def __init__(self, *args, **kwargs):
         super().__init__(*args, **kwargs)
 
+    def test_create_index_statement(self):
+        parser = Parser()
+
+        create_index_query = "CREATE INDEX testindex ON MyVideo (featCol) USING HNSW;"
+        eva_stmt_list = parser.parse(create_index_query)
+
+        # check stmt itself
+        self.assertIsInstance(eva_stmt_list, list)
+        self.assertEqual(len(eva_stmt_list), 1)
+        self.assertEqual(eva_stmt_list[0].stmt_type, StatementType.CREATE_INDEX)
+
+        expected_stmt = CreateIndexStatement(
+            "testindex",
+            TableRef(TableInfo("MyVideo")),
+            [
+                ColumnDefinition("featCol", None, None, None),
+            ],
+            IndexType.HNSW,
+        )
+        actual_stmt = eva_stmt_list[0]
+        self.assertEqual(actual_stmt, expected_stmt)
+
+    @unittest.skip("Skip parser exception handling testcase, moved to binder")
+    def test_create_index_exception_statement(self):
+        parser = Parser()
+
+        create_index_query = (
+            "CREATE INDEX testindex USING HNSW ON MyVideo (featCol1, featCol2);"
+        )
+
+        with self.assertRaises(Exception):
+            parser.parse(create_index_query)
+
     def test_explain_dml_statement(self):
         parser = Parser()
 
@@ -84,7 +122,7 @@ class ParserTests(unittest.TestCase):
 
         # check inner stmt from
         self.assertIsNotNone(
-            inner_stmt.view_ref, TableRef(TableInfo("uadetrac_fastRCNN"))
+            inner_stmt.view_info, TableRef(TableInfo("uadetrac_fastRCNN"))
         )
 
     def test_create_statement(self):
@@ -100,11 +138,40 @@ class ParserTests(unittest.TestCase):
             );"""
         )
 
+        expected_cci = ColConstraintInfo()
+        expected_cci.nullable = True
+        unique_cci = ColConstraintInfo()
+        unique_cci.unique = True
+        unique_cci.nullable = False
+        expected_stmt = CreateTableStatement(
+            TableInfo("Persons"),
+            True,
+            [
+                ColumnDefinition("Frame_ID", ColumnType.INTEGER, None, [], unique_cci),
+                ColumnDefinition(
+                    "Frame_Data", ColumnType.TEXT, None, [10], expected_cci
+                ),
+                ColumnDefinition(
+                    "Frame_Value", ColumnType.FLOAT, None, [1000, 201], expected_cci
+                ),
+                ColumnDefinition(
+                    "Frame_Array",
+                    ColumnType.NDARRAY,
+                    NdArrayType.UINT8,
+                    [5, 100, 2432, 4324, 100],
+                    expected_cci,
+                ),
+            ],
+        )
+        expected_stmt_str = "CREATE TABLE Persons (True)"
+
         for query in single_queries:
             eva_statement_list = parser.parse(query)
             self.assertIsInstance(eva_statement_list, list)
             self.assertEqual(len(eva_statement_list), 1)
             self.assertIsInstance(eva_statement_list[0], AbstractStatement)
+            self.assertEqual(str(eva_statement_list[0]), expected_stmt_str)
+            self.assertEqual(eva_statement_list[0], expected_stmt)
 
     def test_rename_statement(self):
         parser = Parser()
@@ -123,7 +190,7 @@ class ParserTests(unittest.TestCase):
     def test_drop_table_statement(self):
         parser = Parser()
         drop_queries = "DROP TABLE student_info"
-        expected_stmt = DropTableStatement([TableRef(TableInfo("student_info"))], False)
+        expected_stmt = DropTableStatement([TableInfo("student_info")], False)
         eva_statement_list = parser.parse(drop_queries)
         self.assertIsInstance(eva_statement_list, list)
         self.assertEqual(len(eva_statement_list), 1)
@@ -484,13 +551,13 @@ class ParserTests(unittest.TestCase):
 
     def test_load_video_data_statement(self):
         parser = Parser()
-        load_data_query = """LOAD FILE 'data/video.mp4'
-                             INTO MyVideo WITH FORMAT VIDEO;"""
+        load_data_query = """LOAD VIDEO 'data/video.mp4'
+                             INTO MyVideo"""
         file_options = {}
         file_options["file_format"] = FileFormatType.VIDEO
         column_list = None
         expected_stmt = LoadDataStatement(
-            TableRef(TableInfo("MyVideo")),
+            TableInfo("MyVideo"),
             Path("data/video.mp4"),
             column_list,
             file_options,
@@ -505,14 +572,13 @@ class ParserTests(unittest.TestCase):
 
     def test_load_csv_data_statement(self):
         parser = Parser()
-        load_data_query = """LOAD FILE 'data/meta.csv'
+        load_data_query = """LOAD CSV 'data/meta.csv'
                              INTO
-                             MyMeta (id, frame_id, video_id, label)
-                             WITH FORMAT CSV;"""
+                             MyMeta (id, frame_id, video_id, label);"""
         file_options = {}
         file_options["file_format"] = FileFormatType.CSV
         expected_stmt = LoadDataStatement(
-            TableRef(TableInfo("MyMeta")),
+            TableInfo("MyMeta"),
             Path("data/meta.csv"),
             [
                 TupleValueExpression("id"),
@@ -542,7 +608,7 @@ class ParserTests(unittest.TestCase):
         expected_stmt = UploadStatement(
             Path("data/video.mp4"),
             "b'AAAA'",
-            TableRef(TableInfo("MyVideo")),
+            TableInfo("MyVideo"),
             column_list,
             file_options,
         )
@@ -568,7 +634,7 @@ class ParserTests(unittest.TestCase):
         expected_stmt = UploadStatement(
             Path("data/meta.csv"),
             "b'AAAA'",
-            TableRef(TableInfo("MyMeta")),
+            TableInfo("MyMeta"),
             [
                 TupleValueExpression("id"),
                 TupleValueExpression("frame_id"),
@@ -656,7 +722,7 @@ class ParserTests(unittest.TestCase):
         mat_view_stmt = parser.parse(query)
         select_stmt = parser.parse(select_query)
         expected_stmt = CreateMaterializedViewStatement(
-            TableRef(TableInfo("uadtrac_fastRCNN")),
+            TableInfo("uadtrac_fastRCNN"),
             [
                 ColumnDefinition("id", None, None, None),
                 ColumnDefinition("labels", None, None, None),
