@@ -12,18 +12,15 @@
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 # See the License for the specific language governing permissions and
 # limitations under the License.
-import struct
 import unittest
 from unittest.mock import MagicMock
 
 import mock
-from mock import mock_open
 
-from eva.catalog.column_type import ColumnType, NdArrayType
+from eva.catalog.catalog_type import ColumnType, NdArrayType, TableType
 from eva.catalog.models.df_column import DataFrameColumn
 from eva.catalog.models.df_metadata import DataFrameMetadata
-from eva.configuration.configuration_manager import ConfigurationManager
-from eva.storage.storage_engine import VideoStorageEngine
+from eva.storage.storage_engine import StorageEngine
 
 
 class VideoStorageEngineTest(unittest.TestCase):
@@ -32,7 +29,9 @@ class VideoStorageEngineTest(unittest.TestCase):
         self.table = None
 
     def create_sample_table(self):
-        table_info = DataFrameMetadata("dataset", "dataset")
+        table_info = DataFrameMetadata(
+            "dataset", "dataset", table_type=TableType.VIDEO_DATA
+        )
         column_1 = DataFrameColumn("id", ColumnType.INTEGER, False)
         column_2 = DataFrameColumn(
             "data", ColumnType.NDARRAY, False, NdArrayType.UINT8, [2, 2, 3]
@@ -41,11 +40,10 @@ class VideoStorageEngineTest(unittest.TestCase):
         return table_info
 
     def setUp(self):
-        self.video_engine = VideoStorageEngine
+        mock = MagicMock()
+        mock.table_type = TableType.VIDEO_DATA
+        self.video_engine = StorageEngine.factory(mock)
         self.table = self.create_sample_table()
-        self.curr_version = ConfigurationManager().get_value(
-            "storage", "video_engine_version"
-        )
 
     def tearDown(self):
         pass
@@ -56,12 +54,6 @@ class VideoStorageEngineTest(unittest.TestCase):
         with self.assertRaises(FileExistsError):
             self.video_engine.create(self.table, if_not_exists=False)
 
-    def test_invalid_metadata(self):
-        corrupt_meta = struct.pack("!H", self.curr_version + 1)
-        with mock.patch("builtins.open", mock_open(read_data=corrupt_meta)):
-            with self.assertRaises(RuntimeError):
-                list(self.video_engine._get_video_file_path("metadata"))
-
     def test_write(self):
         batch = MagicMock()
         batch.frames = []
